<?php
/*
Plugin Name: 아임포트 결제버튼 생성 플러그인
Plugin URI: http://www.iamport.kr
Description: 원하는 위치에 자유자재로 결제버튼을 생성하실 수 있는 아임포트 플러그인입니다. 국내 PG사의 다양한 결제수단을 이용하실 수 있습니다. ( 신용카드 / 실시간계좌이체 / 가상계좌 / 휴대폰소액결제 - 에스크로포함 )
Version: 0.32
Author: SIOT
Author URI: http://www.siot.do
*/
if ( !class_exists('IamportPaymentPlugin') ) {
	require_once 'shortcode.php';

	class IamportPaymentPlugin {
		
		private $user_code;
		private $api_key;
		private $api_secret;
		private $shortcode;

		public function __construct() {
			if( is_admin() ) {
				add_action('admin_menu', array( $this, 'iamport_admin_menu') );
			}

			add_action('init', array($this, 'init') );
			add_action('wp_enqueue_scripts', array($this, 'iamport_script_enqueue'), 99);
		}

		public function init() {
			$this->user_code = get_option('iamport_user_code');
			$this->api_key = get_option('iamport_rest_key');
			$this->api_secret = get_option('iamport_rest_secret');

			$this->shortcode = new IamportShortcode($this->user_code, $this->api_key, $this->api_secret);
		}

		public function iamport_admin_menu() {
			add_menu_page( '아임포트 결제설정', '아임포트 결제설정', 'administrator', dirname(__FILE__), array($this, 'iamport_admin_page'), plugin_dir_url( __FILE__ ) . 'img/iamport.jpg' );
		}

		public function iamport_script_enqueue($hook) {
			wp_deregister_script( 'iamport-payment-sdk' );
			wp_register_script( 'iamport-payment-sdk', 'https://service.iamport.kr/js/iamport.payment.js', array( 'jquery' ) );
			wp_enqueue_script( 'iamport-payment-sdk' );
		}

		public function iamport_admin_page() {
			ob_start();
			?>
				<div class="wrap">
					<h2>아임포트 결제설정 페이지</h2>
					<p>
						<h3>아임포트 결제정보 설정</h3>
						<form method="post" action="">
							<table class="form-table">
								<tbody>
									<tr valign="top">
										<th scope="row" style="width:160px;"><label for="iamport_user_code">[아임포트] 가맹점 식별코드</label></th>
										<td>
											<input class="regular-text" name="iamport_user_code" type="text" id="iamport_user_code" value="<?=$this->user_code?>" /><br>
											<a target="_blank" href="https://admin.iamport.kr">https://admin.iamport.kr</a> 에서 회원가입 후, "시스템설정" > "내정보"에서 확인하실 수 있습니다.
										</td>
									</tr>
									<tr valign="top">
										<th scope="row" style="width:160px;"><label for="iamport_rest_key">[아임포트] REST API 키</label></th>
										<td>
											<input class="regular-text" name="iamport_rest_key" type="text" id="iamport_rest_key" value="<?=$this->api_key?>" /><br>
											<a target="_blank" href="https://admin.iamport.kr">https://admin.iamport.kr</a> 에서 회원가입 후, "시스템설정" > "내정보"에서 확인하실 수 있습니다.
										</td>
									</tr>
									<tr valign="top">
										<th scope="row" style="width:160px;"><label for="iamport_rest_secret">[아임포트] REST API Secret</label></th>
										<td>
											<input class="regular-text" name="iamport_rest_secret" type="text" id="iamport_rest_secret" value="<?=$this->api_secret?>" /><br>
											<a target="_blank" href="https://admin.iamport.kr">https://admin.iamport.kr</a> 에서 회원가입 후, "시스템설정" > "내정보"에서 확인하실 수 있습니다.
										</td>
									</tr>
								</tbody>
							</table>
							
							<?php wp_nonce_field('iamport-options', 'iamport-settings'); ?>
							<input type="hidden" name="action" value="update_iamport_settings" />
							<input class="button-primary" type="submit" name="iamport-options" value="저장하기" />
						</form>
					</p>
				</div>
			<?php 
			ob_end_flush();
		}

	}

	new IamportPaymentPlugin($user_code, $api_key, $api_secret);
}


//iamport 결제설정 정보 저장
if (isset($_POST['action']) && $_POST['action'] == "update_iamport_settings"){
	require_once(ABSPATH .'wp-includes/pluggable.php');
	if (wp_verify_nonce($_POST['iamport-settings'],'iamport-options')){
		update_option('iamport_user_code',$_POST['iamport_user_code']);
		update_option('iamport_rest_key',$_POST['iamport_rest_key']);
		update_option('iamport_rest_secret',$_POST['iamport_rest_secret']);
	}else{ ?>
		<div class="error">update failed</div><?php
	}
}